# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types import (
    EmailProcessBouncedEmailResponse,
    EmailCaptureBouncedEmailsResponse,
    EmailKickoffCommentUpdateResponse,
    EmailKickoffGeneralUpdateResponse,
    EmailProcessCommentUpdateResponse,
    EmailProcessGeneralUpdateResponse,
    EmailCaptureResendBouncedEmailResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmails:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_capture_bounced_emails(self, client: AlphaxivCat) -> None:
        email = client.emails.capture_bounced_emails(
            message="Message",
            type="Type",
        )
        assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_capture_bounced_emails(self, client: AlphaxivCat) -> None:
        response = client.emails.with_raw_response.capture_bounced_emails(
            message="Message",
            type="Type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_capture_bounced_emails(self, client: AlphaxivCat) -> None:
        with client.emails.with_streaming_response.capture_bounced_emails(
            message="Message",
            type="Type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_capture_resend_bounced_email(self, client: AlphaxivCat) -> None:
        email = client.emails.capture_resend_bounced_email(
            data={},
            type="type",
        )
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_capture_resend_bounced_email_with_all_params(self, client: AlphaxivCat) -> None:
        email = client.emails.capture_resend_bounced_email(
            data={"to": ["string"]},
            type="type",
        )
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_capture_resend_bounced_email(self, client: AlphaxivCat) -> None:
        response = client.emails.with_raw_response.capture_resend_bounced_email(
            data={},
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_capture_resend_bounced_email(self, client: AlphaxivCat) -> None:
        with client.emails.with_streaming_response.capture_resend_bounced_email(
            data={},
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_comment_update(self, client: AlphaxivCat) -> None:
        email = client.emails.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        )
        assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_comment_update(self, client: AlphaxivCat) -> None:
        response = client.emails.with_raw_response.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_comment_update(self, client: AlphaxivCat) -> None:
        with client.emails.with_streaming_response.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_kickoff_comment_update(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `role` but received ''"):
            client.emails.with_raw_response.kickoff_comment_update(
                custom="true",
                role="",
                window="window",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `window` but received ''"):
            client.emails.with_raw_response.kickoff_comment_update(
                custom="true",
                role="role",
                window="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_general_update(self, client: AlphaxivCat) -> None:
        email = client.emails.kickoff_general_update(
            "role",
        )
        assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_general_update(self, client: AlphaxivCat) -> None:
        response = client.emails.with_raw_response.kickoff_general_update(
            "role",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_general_update(self, client: AlphaxivCat) -> None:
        with client.emails.with_streaming_response.kickoff_general_update(
            "role",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_kickoff_general_update(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `role` but received ''"):
            client.emails.with_raw_response.kickoff_general_update(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_bounced_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = client.emails.process_bounced_email(
                email="dev@stainless.com",
            )

        assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_bounced_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.emails.with_raw_response.process_bounced_email(
                email="dev@stainless.com",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_bounced_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.emails.with_streaming_response.process_bounced_email(
                email="dev@stainless.com",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = response.parse()
                assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_comment_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = client.emails.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_comment_update_with_all_params(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = client.emails.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                custom_content={
                    "events": [
                        {
                            "date": "date",
                            "description": "description",
                            "link": "link",
                            "title": "title",
                            "end_time_raw": "endTimeRaw",
                            "start_time_raw": "startTimeRaw",
                        }
                    ],
                    "intro_text": "introText",
                    "subject": "subject",
                },
            )

        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_comment_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.emails.with_raw_response.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_comment_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.emails.with_streaming_response.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = response.parse()
                assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_general_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = client.emails.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_general_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.emails.with_raw_response.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_general_update(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.emails.with_streaming_response.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = response.parse()
                assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncEmails:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_capture_bounced_emails(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.emails.capture_bounced_emails(
            message="Message",
            type="Type",
        )
        assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_capture_bounced_emails(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.emails.with_raw_response.capture_bounced_emails(
            message="Message",
            type="Type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_capture_bounced_emails(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.emails.with_streaming_response.capture_bounced_emails(
            message="Message",
            type="Type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailCaptureBouncedEmailsResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_capture_resend_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.emails.capture_resend_bounced_email(
            data={},
            type="type",
        )
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_capture_resend_bounced_email_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.emails.capture_resend_bounced_email(
            data={"to": ["string"]},
            type="type",
        )
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_capture_resend_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.emails.with_raw_response.capture_resend_bounced_email(
            data={},
            type="type",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_capture_resend_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.emails.with_streaming_response.capture_resend_bounced_email(
            data={},
            type="type",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailCaptureResendBouncedEmailResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.emails.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        )
        assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.emails.with_raw_response.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.emails.with_streaming_response.kickoff_comment_update(
            custom="true",
            role="role",
            window="window",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailKickoffCommentUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_kickoff_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `role` but received ''"):
            await async_client.emails.with_raw_response.kickoff_comment_update(
                custom="true",
                role="",
                window="window",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `window` but received ''"):
            await async_client.emails.with_raw_response.kickoff_comment_update(
                custom="true",
                role="role",
                window="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.emails.kickoff_general_update(
            "role",
        )
        assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.emails.with_raw_response.kickoff_general_update(
            "role",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.emails.with_streaming_response.kickoff_general_update(
            "role",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailKickoffGeneralUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_kickoff_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `role` but received ''"):
            await async_client.emails.with_raw_response.kickoff_general_update(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = await async_client.emails.process_bounced_email(
                email="dev@stainless.com",
            )

        assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.emails.with_raw_response.process_bounced_email(
                email="dev@stainless.com",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_bounced_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.emails.with_streaming_response.process_bounced_email(
                email="dev@stainless.com",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = await response.parse()
                assert_matches_type(EmailProcessBouncedEmailResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = await async_client.emails.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_comment_update_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = await async_client.emails.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                custom_content={
                    "events": [
                        {
                            "date": "date",
                            "description": "description",
                            "link": "link",
                            "title": "title",
                            "end_time_raw": "endTimeRaw",
                            "start_time_raw": "startTimeRaw",
                        }
                    ],
                    "intro_text": "introText",
                    "subject": "subject",
                },
            )

        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.emails.with_raw_response.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_comment_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.emails.with_streaming_response.process_comment_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = await response.parse()
                assert_matches_type(EmailProcessCommentUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            email = await async_client.emails.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.emails.with_raw_response.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_general_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.emails.with_streaming_response.process_general_update(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                email = await response.parse()
                assert_matches_type(EmailProcessGeneralUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.retrieve import v1_get_top_papers_params

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def get_top_papers(
        self,
        *,
        limit: str | Omit = omit,
        skip: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Get the top AI papers

        Source file:
        `api-server/src/controllers/retrieve/v1/retrieve-top-papers.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/retrieve/v1/top-papers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "skip": skip,
                    },
                    v1_get_top_papers_params.V1GetTopPapersParams,
                ),
            ),
            cast_to=object,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def get_top_papers(
        self,
        *,
        limit: str | Omit = omit,
        skip: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Get the top AI papers

        Source file:
        `api-server/src/controllers/retrieve/v1/retrieve-top-papers.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/retrieve/v1/top-papers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "skip": skip,
                    },
                    v1_get_top_papers_params.V1GetTopPapersParams,
                ),
            ),
            cast_to=object,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_top_papers = to_raw_response_wrapper(
            v1.get_top_papers,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_top_papers = async_to_raw_response_wrapper(
            v1.get_top_papers,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_top_papers = to_streamed_response_wrapper(
            v1.get_top_papers,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_top_papers = async_to_streamed_response_wrapper(
            v1.get_top_papers,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .briefs import (
    BriefsResource,
    AsyncBriefsResource,
    BriefsResourceWithRawResponse,
    AsyncBriefsResourceWithRawResponse,
    BriefsResourceWithStreamingResponse,
    AsyncBriefsResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "BriefsResource",
    "AsyncBriefsResource",
    "BriefsResourceWithRawResponse",
    "AsyncBriefsResourceWithRawResponse",
    "BriefsResourceWithStreamingResponse",
    "AsyncBriefsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ImplementationDeleteParams"]


class ImplementationDeleteParams(TypedDict, total=False):
    paper_group_id: Required[Annotated[str, PropertyInfo(alias="paperGroupId")]]

    type: Required[Literal["alphaxiv", "resource"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["PaperViewCountProcessJobResponse", "Data"]


class Data(BaseModel):
    processed_paper: str = FieldInfo(alias="processedPaper")


class PaperViewCountProcessJobResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["EventListResponse", "EventListResponseItem"]


class EventListResponseItem(BaseModel):
    id: str

    date: str

    link: str

    organization: str

    recording: Optional[str] = None

    speaker: str

    title: str


EventListResponse: TypeAlias = List[EventListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import TypeAlias

__all__ = ["V1GetTotalUserCountResponse"]

V1GetTotalUserCountResponse: TypeAlias = float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .arxiv import (
    ArxivResource,
    AsyncArxivResource,
    ArxivResourceWithRawResponse,
    AsyncArxivResourceWithRawResponse,
    ArxivResourceWithStreamingResponse,
    AsyncArxivResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "ArxivResource",
    "AsyncArxivResource",
    "ArxivResourceWithRawResponse",
    "AsyncArxivResourceWithRawResponse",
    "ArxivResourceWithStreamingResponse",
    "AsyncArxivResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3RetrieveSimilarPapersParams"]


class V3RetrieveSimilarPapersParams(TypedDict, total=False):
    exclude: str

    exclude_likes: Annotated[Literal["false", "true"], PropertyInfo(alias="excludeLikes")]

    interval: Literal["3 Days", "7 Days", "30 Days", "90 Days", "All time"]

    limit: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .folders import (
    FoldersResource,
    AsyncFoldersResource,
    FoldersResourceWithRawResponse,
    AsyncFoldersResourceWithRawResponse,
    FoldersResourceWithStreamingResponse,
    AsyncFoldersResourceWithStreamingResponse,
)

__all__ = [
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
    "FoldersResource",
    "AsyncFoldersResource",
    "FoldersResourceWithRawResponse",
    "AsyncFoldersResourceWithRawResponse",
    "FoldersResourceWithStreamingResponse",
    "AsyncFoldersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.search.v2 import paper_fast_search_params
from ....types.search.v2.paper_fast_search_response import PaperFastSearchResponse

__all__ = ["PaperResource", "AsyncPaperResource"]


class PaperResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PaperResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return PaperResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PaperResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return PaperResourceWithStreamingResponse(self)

    def fast_search(
        self,
        *,
        include_private: Literal["true", "false"],
        q: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperFastSearchResponse:
        """
        Search for public and optionally private papers

        Source file:
        `api-server/src/controllers/search/v2/search-google-fast.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/search/v2/paper/fast",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "include_private": include_private,
                        "q": q,
                    },
                    paper_fast_search_params.PaperFastSearchParams,
                ),
            ),
            cast_to=PaperFastSearchResponse,
        )


class AsyncPaperResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPaperResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPaperResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPaperResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncPaperResourceWithStreamingResponse(self)

    async def fast_search(
        self,
        *,
        include_private: Literal["true", "false"],
        q: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperFastSearchResponse:
        """
        Search for public and optionally private papers

        Source file:
        `api-server/src/controllers/search/v2/search-google-fast.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/search/v2/paper/fast",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "include_private": include_private,
                        "q": q,
                    },
                    paper_fast_search_params.PaperFastSearchParams,
                ),
            ),
            cast_to=PaperFastSearchResponse,
        )


class PaperResourceWithRawResponse:
    def __init__(self, paper: PaperResource) -> None:
        self._paper = paper

        self.fast_search = to_raw_response_wrapper(
            paper.fast_search,
        )


class AsyncPaperResourceWithRawResponse:
    def __init__(self, paper: AsyncPaperResource) -> None:
        self._paper = paper

        self.fast_search = async_to_raw_response_wrapper(
            paper.fast_search,
        )


class PaperResourceWithStreamingResponse:
    def __init__(self, paper: PaperResource) -> None:
        self._paper = paper

        self.fast_search = to_streamed_response_wrapper(
            paper.fast_search,
        )


class AsyncPaperResourceWithStreamingResponse:
    def __init__(self, paper: AsyncPaperResource) -> None:
        self._paper = paper

        self.fast_search = async_to_streamed_response_wrapper(
            paper.fast_search,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3GetClaimedPapersResponse", "V3GetClaimedPapersResponseItem"]


class V3GetClaimedPapersResponseItem(BaseModel):
    id: str

    abstract: str

    authors: List[str]

    citations: float

    google_citation_id: Optional[str] = None

    image_url: Optional[str] = FieldInfo(alias="imageURL", default=None)

    paper_id: str
    """A versionless universal paper ID (e.g. 1706.03762)"""

    public_total_votes: float

    publication_date: str

    title: str

    topics: List[str]


V3GetClaimedPapersResponse: TypeAlias = List[V3GetClaimedPapersResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .paper_fast_search_params import PaperFastSearchParams as PaperFastSearchParams
from .paper_fast_search_response import PaperFastSearchResponse as PaperFastSearchResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .topics import (
    TopicsResource,
    AsyncTopicsResource,
    TopicsResourceWithRawResponse,
    AsyncTopicsResourceWithRawResponse,
    TopicsResourceWithStreamingResponse,
    AsyncTopicsResourceWithStreamingResponse,
)
from .following import (
    FollowingResource,
    AsyncFollowingResource,
    FollowingResourceWithRawResponse,
    AsyncFollowingResourceWithRawResponse,
    FollowingResourceWithStreamingResponse,
    AsyncFollowingResourceWithStreamingResponse,
)
from .organizations import (
    OrganizationsResource,
    AsyncOrganizationsResource,
    OrganizationsResourceWithRawResponse,
    AsyncOrganizationsResourceWithRawResponse,
    OrganizationsResourceWithStreamingResponse,
    AsyncOrganizationsResourceWithStreamingResponse,
)

__all__ = [
    "TopicsResource",
    "AsyncTopicsResource",
    "TopicsResourceWithRawResponse",
    "AsyncTopicsResourceWithRawResponse",
    "TopicsResourceWithStreamingResponse",
    "AsyncTopicsResourceWithStreamingResponse",
    "OrganizationsResource",
    "AsyncOrganizationsResource",
    "OrganizationsResourceWithRawResponse",
    "AsyncOrganizationsResourceWithRawResponse",
    "OrganizationsResourceWithStreamingResponse",
    "AsyncOrganizationsResourceWithStreamingResponse",
    "FollowingResource",
    "AsyncFollowingResource",
    "FollowingResourceWithRawResponse",
    "AsyncFollowingResourceWithRawResponse",
    "FollowingResourceWithStreamingResponse",
    "AsyncFollowingResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V3AutocompleteProfileResponse"]


class V3AutocompleteProfileResponse(BaseModel):
    bio: str

    institution: str

    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["IngestIngestLatestResponse", "Data", "DataPdfInfo"]


class DataPdfInfo(BaseModel):
    fetcher_url: str


class Data(BaseModel):
    authors: List[Optional[object]]

    max_version_order: float

    pdf_info: DataPdfInfo

    verified_authors: List[Optional[object]]

    paper_group: Optional[object] = None

    paper_version: Optional[object] = None


class IngestIngestLatestResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "LegacyRetrieveCommentsResponse",
    "LegacyRetrieveCommentsResponseItem",
    "LegacyRetrieveCommentsResponseItemAnnotation",
    "LegacyRetrieveCommentsResponseItemAnnotationAnchorPosition",
    "LegacyRetrieveCommentsResponseItemAnnotationFocusPosition",
    "LegacyRetrieveCommentsResponseItemAnnotationHighlightRect",
    "LegacyRetrieveCommentsResponseItemAnnotationHighlightRectRect",
    "LegacyRetrieveCommentsResponseItemAuthor",
    "LegacyRetrieveCommentsResponseItemAuthorAvatar",
    "LegacyRetrieveCommentsResponseItemEndorsement",
    "LegacyRetrieveCommentsResponseItemResponse",
    "LegacyRetrieveCommentsResponseItemResponseAnnotation",
    "LegacyRetrieveCommentsResponseItemResponseAnnotationAnchorPosition",
    "LegacyRetrieveCommentsResponseItemResponseAnnotationFocusPosition",
    "LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRect",
    "LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRectRect",
    "LegacyRetrieveCommentsResponseItemResponseAuthor",
    "LegacyRetrieveCommentsResponseItemResponseAuthorAvatar",
    "LegacyRetrieveCommentsResponseItemResponseEndorsement",
]


class LegacyRetrieveCommentsResponseItemAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class LegacyRetrieveCommentsResponseItemAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class LegacyRetrieveCommentsResponseItemAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class LegacyRetrieveCommentsResponseItemAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[LegacyRetrieveCommentsResponseItemAnnotationHighlightRectRect]


class LegacyRetrieveCommentsResponseItemAnnotation(BaseModel):
    anchor_position: LegacyRetrieveCommentsResponseItemAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: LegacyRetrieveCommentsResponseItemAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[LegacyRetrieveCommentsResponseItemAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class LegacyRetrieveCommentsResponseItemAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class LegacyRetrieveCommentsResponseItemAuthor(BaseModel):
    id: str

    avatar: Optional[List[LegacyRetrieveCommentsResponseItemAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class LegacyRetrieveCommentsResponseItemEndorsement(BaseModel):
    id: str

    name: str


class LegacyRetrieveCommentsResponseItemResponseAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class LegacyRetrieveCommentsResponseItemResponseAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRectRect]


class LegacyRetrieveCommentsResponseItemResponseAnnotation(BaseModel):
    anchor_position: LegacyRetrieveCommentsResponseItemResponseAnnotationAnchorPosition = FieldInfo(
        alias="anchorPosition"
    )

    focus_position: LegacyRetrieveCommentsResponseItemResponseAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[LegacyRetrieveCommentsResponseItemResponseAnnotationHighlightRect] = FieldInfo(
        alias="highlightRects"
    )

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class LegacyRetrieveCommentsResponseItemResponseAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class LegacyRetrieveCommentsResponseItemResponseAuthor(BaseModel):
    id: str

    avatar: Optional[List[LegacyRetrieveCommentsResponseItemResponseAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class LegacyRetrieveCommentsResponseItemResponseEndorsement(BaseModel):
    id: str

    name: str


class LegacyRetrieveCommentsResponseItemResponse(BaseModel):
    id: str

    annotation: Optional[LegacyRetrieveCommentsResponseItemResponseAnnotation] = None

    author: LegacyRetrieveCommentsResponseItemResponseAuthor

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[LegacyRetrieveCommentsResponseItemResponseEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class LegacyRetrieveCommentsResponseItem(BaseModel):
    id: str

    annotation: Optional[LegacyRetrieveCommentsResponseItemAnnotation] = None

    author: LegacyRetrieveCommentsResponseItemAuthor

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[LegacyRetrieveCommentsResponseItemEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    responses: List[LegacyRetrieveCommentsResponseItemResponse]

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


LegacyRetrieveCommentsResponse: TypeAlias = List[LegacyRetrieveCommentsResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.users.v3.by_username_get_user_response import ByUsernameGetUserResponse
from ....types.users.v3.by_username_get_profile_page_response import ByUsernameGetProfilePageResponse

__all__ = ["ByUsernameResource", "AsyncByUsernameResource"]


class ByUsernameResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ByUsernameResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return ByUsernameResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ByUsernameResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return ByUsernameResourceWithStreamingResponse(self)

    def get_profile_page(
        self,
        username: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ByUsernameGetProfilePageResponse:
        """
        This route is specifically for the Client's user page

        Source file:
        `api-server/src/controllers/users/v3/get-profile-page-by-username.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not username:
            raise ValueError(f"Expected a non-empty value for `username` but received {username!r}")
        return self._get(
            f"/users/v3/by-username/{username}/profile-page",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ByUsernameGetProfilePageResponse,
        )

    def get_user(
        self,
        username: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ByUsernameGetUserResponse:
        """
        Retrieve a user's basic information given its username

        Source file:
        `api-server/src/controllers/users/v3/get-user-by-username.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not username:
            raise ValueError(f"Expected a non-empty value for `username` but received {username!r}")
        return self._get(
            f"/users/v3/by-username/{username}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ByUsernameGetUserResponse,
        )


class AsyncByUsernameResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncByUsernameResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncByUsernameResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncByUsernameResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncByUsernameResourceWithStreamingResponse(self)

    async def get_profile_page(
        self,
        username: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ByUsernameGetProfilePageResponse:
        """
        This route is specifically for the Client's user page

        Source file:
        `api-server/src/controllers/users/v3/get-profile-page-by-username.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not username:
            raise ValueError(f"Expected a non-empty value for `username` but received {username!r}")
        return await self._get(
            f"/users/v3/by-username/{username}/profile-page",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ByUsernameGetProfilePageResponse,
        )

    async def get_user(
        self,
        username: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ByUsernameGetUserResponse:
        """
        Retrieve a user's basic information given its username

        Source file:
        `api-server/src/controllers/users/v3/get-user-by-username.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not username:
            raise ValueError(f"Expected a non-empty value for `username` but received {username!r}")
        return await self._get(
            f"/users/v3/by-username/{username}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ByUsernameGetUserResponse,
        )


class ByUsernameResourceWithRawResponse:
    def __init__(self, by_username: ByUsernameResource) -> None:
        self._by_username = by_username

        self.get_profile_page = to_raw_response_wrapper(
            by_username.get_profile_page,
        )
        self.get_user = to_raw_response_wrapper(
            by_username.get_user,
        )


class AsyncByUsernameResourceWithRawResponse:
    def __init__(self, by_username: AsyncByUsernameResource) -> None:
        self._by_username = by_username

        self.get_profile_page = async_to_raw_response_wrapper(
            by_username.get_profile_page,
        )
        self.get_user = async_to_raw_response_wrapper(
            by_username.get_user,
        )


class ByUsernameResourceWithStreamingResponse:
    def __init__(self, by_username: ByUsernameResource) -> None:
        self._by_username = by_username

        self.get_profile_page = to_streamed_response_wrapper(
            by_username.get_profile_page,
        )
        self.get_user = to_streamed_response_wrapper(
            by_username.get_user,
        )


class AsyncByUsernameResourceWithStreamingResponse:
    def __init__(self, by_username: AsyncByUsernameResource) -> None:
        self._by_username = by_username

        self.get_profile_page = async_to_streamed_response_wrapper(
            by_username.get_profile_page,
        )
        self.get_user = async_to_streamed_response_wrapper(
            by_username.get_user,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3RetrieveMetricsResponse"]


class V3RetrieveMetricsResponse(BaseModel):
    comments_count: float = FieldInfo(alias="commentsCount")

    public_total_votes: float = FieldInfo(alias="publicTotalVotes")

    visits_all: float = FieldInfo(alias="visitsAll")
